<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=pt
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'O guia oferece assistência aos utilizadores durante a sua primeira visita à área privada de SPIP.', # MODIF
	'compagnon_nom' => 'Guia',
	'compagnon_slogan' => 'Assistente de iniciação a SPIP',
];
